@@ -60,7 +60,7 @@ typedef enum
 
 struct _GduWindow
 {
-  GtkWindow parent_instance;
+  GtkApplicationWindow parent_instance;
 
   GduApplication *application;
   UDisksClient *client;
@@ -181,7 +181,7 @@ static const struct {
 
 typedef struct
 {
-  GtkWindowClass parent_class;
+  GtkApplicationWindowClass parent_class;
 } GduWindowClass;
 
 enum
@@ -273,7 +273,7 @@ static void on_generic_menu_item_create_volume_image (GtkMenuItem *menu_item,
 static void on_generic_menu_item_restore_volume_image (GtkMenuItem *menu_item,
                                                        gpointer   user_data);
 
-G_DEFINE_TYPE (GduWindow, gdu_window, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE (GduWindow, gdu_window, GTK_TYPE_APPLICATION_WINDOW);
 
 static void
 gdu_window_init (GduWindow *window)
@@ -626,11 +626,9 @@ loop_setup_cb (UDisksManager  *manager,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static void
-on_device_tree_attach_disk_image_button_clicked (GtkToolButton *button,
-                                                 gpointer       user_data)
+void
+gdu_window_show_attach_disk_image (GduWindow *window)
 {
-  GduWindow *window = GDU_WINDOW (user_data);
   GtkWidget *dialog;
   gchar *filename;
   gint fd;
@@ -697,6 +695,14 @@ on_device_tree_attach_disk_image_button_clicked (GtkToolButton *button,
   g_free (filename);
 }
 
+static void
+on_device_tree_attach_disk_image_button_clicked (GtkToolButton *button,
+                                                 gpointer       user_data)
+{
+  GduWindow *window = GDU_WINDOW (user_data);
+  gdu_window_show_attach_disk_image (window);
+}
+
 /* ---------------------------------------------------------------------------------------------------- */
 
 gboolean
@@ -831,6 +837,25 @@ on_constructed_in_idle (gpointer user_data)
   return FALSE; /* remove source */
 }
 
+static gint
+device_sort_function (GtkTreeModel *model,
+                      GtkTreeIter *a,
+                      GtkTreeIter *b,
+                      gpointer user_data)
+{
+  gchar *sa, *sb;
+
+  gtk_tree_model_get (model, a,
+                      GDU_DEVICE_TREE_MODEL_COLUMN_SORT_KEY, &sa,
+                      -1);
+  gtk_tree_model_get (model, b,
+                      GDU_DEVICE_TREE_MODEL_COLUMN_SORT_KEY, &sb,
+                      -1);
+
+  return g_strcmp0 (sa, sb);
+}
+
+
 static void
 gdu_window_constructed (GObject *object)
 {
@@ -899,6 +924,12 @@ gdu_window_constructed (GObject *object)
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (window->model),
                                         GDU_DEVICE_TREE_MODEL_COLUMN_SORT_KEY,
                                         GTK_SORT_ASCENDING);
+  /* Force g_strcmp0() as the sort function otherwise ___aa won't come before ____b ... */
+  gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (window->model),
+                                   GDU_DEVICE_TREE_MODEL_COLUMN_SORT_KEY,
+                                   device_sort_function,
+                                   NULL, /* user_data */
+                                   NULL); /* GDestroyNotify */
 
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->device_treeview));
   gtk_tree_selection_set_select_function (selection, dont_select_headings, NULL, NULL);
